@@ -6,12 +6,10 @@ from django.db import models
 from django.conf import settings
 from django.utils.safestring import mark_safe
 
-from . import statuses
-
 
 class ExportJob(models.Model):
     file = models.FileField(upload_to='django-export-celery-jobs/', blank=False, null=False, max_length=255)
-    status = models.CharField(max_length=25, null=True, default=None, choices=zip(statuses.STATUSES, statuses.STATUSES))
+    status = models.CharField(max_length=25, null=True, default=None)
     model = models.CharField(max_length=255, default='')
     resource = models.CharField(max_length=255, default='')
     started_on = models.DateTimeField(auto_now_add=True)
